@@ -46,7 +46,7 @@ def hcl_to_json(file_path):
         with open(file_path, 'r', encoding="utf-8") as fp:
             json_data = parser.loads(fp)
             # json_data = hcl2.load(fp)
-            json_data = remove_list_from_values(json_data)
+            # json_data = remove_list_from_values(json_data)
     except Exception:
         try:
             with open(file_path, 'r', encoding="utf-8") as fp:
